@@ -944,7 +944,7 @@ static void xrun(void)
 		}
 		return;		/* ok, data should be accepted again */
 	}
-	error("read/write error");
+	error("read/write error, state = %s", snd_pcm_state_name(snd_pcm_status_get_state(status)));
 	exit(EXIT_FAILURE);
 }
 
@@ -1793,6 +1793,7 @@ static void playback(char *name)
 	size_t dta;
 	ssize_t dtawave;
 
+	pbrec_count = (size_t)-1;
 	fdcount = 0;
 	if (!name || !strcmp(name, "-")) {
 		fd = fileno(stdin);
@@ -1843,6 +1844,7 @@ static void playback(char *name)
 
 static void capture(char *name)
 {
+	pbrec_count = (size_t)-1;
 	if (!name || !strcmp(name, "-")) {
 		fd = fileno(stdout);
 		name = "stdout";
